<!--
https://pypi.org/project/readme-generator/
https://pypi.org/project/python-readme-generator/
https://pypi.org/project/django-readme-generator/
-->

[![](https://img.shields.io/pypi/pyversions/django-admin-parent-filter.svg?longCache=True)](https://pypi.org/project/django-admin-parent-filter/)

#### Installation
```bash
$ [sudo] pip install django-admin-parent-filter
```

#### Classes
class|`__doc__`
-|-
`django_admin_parent_filter.ParentFilter` |django admin Parent filter

<p align="center">
    <a href="https://pypi.org/project/django-readme-generator/">django-readme-generator</a>
</p>